@@ -4,4 +4,4 @@ from __future__ import absolute_import
 
 # import apis into api package
 from hubspot.crm.schemas.api.core_api import CoreApi
-from hubspot.crm.schemas.api.default_api import DefaultApi
+from hubspot.crm.schemas.api.public_object_schemas_api import PublicObjectSchemasApi
